@@ -1,7 +1,7 @@
+import re
 from os.path import normpath
 from pathlib import Path
 
-from markdownup.access_control import AccessControl
 from markdownup.auth.auth_provider import AuthProvider
 from markdownup.config import Config
 from markdownup.filesystem.asset_file import AssetFile
@@ -14,7 +14,7 @@ class MarkdownUp:
 
     def __init__(self, config: Config):
         self.config = config
-        self.global_access_control = AccessControl(config.get('access', 'global'))
+        self.exclusions = list(map(lambda e: re.compile(e), config.get('content', 'exclusions')))
         self.root_path = Path(config.get('content', 'root')).resolve()
         self.root = Directory(self)
         self.theme = Theme(config)
